==> estateplat-common-1.2.4-20200804.123043-406-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwfzxx.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc 房屋多幢信息
 * Date: 15-4-17
 * Time: 下午3:17
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "bdc_fwfzxx")
public class BdcFwfzxx implements InsertVo, Serializable {
    @Id
    private String fzid;//房屋id
    private String qlid;//权利id
    private String xmmc;//项目名称
    private String zh;//幢号
    private String zcs;//总层数
    private String ghyt;//规划用途
    private String fwjg;//房屋结构
    private Double jzmj;//建筑面积
    private Date jgsj;//竣工时间
    private Integer zts;//总套数
    private String fwxz;//zwq 显示该项目的房屋的性质
    private String szc;//sc  所在层
    private Double zzdmj;//幢占地面积
    private Integer jznd;//建筑年代
    private String jcnd;//建成年代
    private String fwbm;//房屋编码
    private String fjh;//房间号


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fwfzxx表增加冗余字段bdcdybh
     */
    private String bdcdybh; //不动产单元编号

    private String fsss;//附属设施

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getFzid() {
        return fzid;
    }

    public void setFzid(String fzid) {
        this.fzid = fzid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getFsss() {
        return fsss;
    }

    public void setFsss(String fsss) {
        this.fsss = fsss;
    }

    public String getJcnd() {
        return jcnd;
    }

    public void setJcnd(String jcnd) {
        this.jcnd = jcnd;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }
}

==> estateplat-common-1.2.4-20210831.083008-858-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwfzxx.java <==
package cn.gtmap.estateplat.model.server.core;


import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc 房屋多幢信息
 * Date: 15-4-17
 * Time: 下午3:17
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "bdc_fwfzxx")
public class BdcFwfzxx implements InsertVo, Serializable {
    @Id
    private String fzid;//房屋id
    private String qlid;//权利id
    private String xmmc;//项目名称
    private String zh;//幢号
    private String zcs;//总层数
    private String ghyt;//规划用途
    private String fwjg;//房屋结构
    private Double jzmj;//建筑面积
    private Date jgsj;//竣工时间
    private Integer zts;//总套数
    private String fwxz;//zwq 显示该项目的房屋的性质
    private String szc;//sc  所在层
    private Double zzdmj;//幢占地面积
    private Integer jznd;//建筑年代
    private String jcnd;//建成年代
    private String fwbm;//房屋编码
    private String fjh;//房间号


    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fwfzxx表增加冗余字段bdcdybh
     */
    private String bdcdybh; //不动产单元编号

    private String fsss;//附属设施

    private String ytmc;// 用途名称
    private String pzyt;//批准用途
    private String fwxzmc;//房屋性质名称

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getFzid() {
        return fzid;
    }

    public void setFzid(String fzid) {
        this.fzid = fzid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }

    public Integer getJznd() {
        return jznd;
    }

    public void setJznd(Integer jznd) {
        this.jznd = jznd;
    }

    public String getFsss() {
        return fsss;
    }

    public void setFsss(String fsss) {
        this.fsss = fsss;
    }

    public String getJcnd() {
        return jcnd;
    }

    public void setJcnd(String jcnd) {
        this.jcnd = jcnd;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }
}
